==> foundation-2.6.1.tgz: package/Volume/Volume.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const Volume = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M78.864 17.021c-.026-.026-.056-.042-.082-.067l.008-.008-1.924-1.923-.022.022a2.696 2.696 0 00-3.553.161l-.004-.004-3.419 3.418.023.023a2.693 2.693 0 00.01 3.345l-.022.022.216.216 1.707 1.708.031-.031c.025.026.042.057.067.083 14.358 14.358 14.401 37.688.138 52.104l-.019-.019-1.707 1.707-.216.216.022.022a2.698 2.698 0 00.16 3.553l-.004.004 3.42 3.42.023-.023a2.693 2.693 0 003.345-.011l.022.022.216-.216 1.707-1.707-.004-.004c18.102-18.257 18.058-47.835-.139-66.033z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M69.376 30.198c-.026-.026-.056-.042-.082-.067l.008-.008-1.925-1.923-.022.022a2.7 2.7 0 00-3.554.16l-.004-.004-.035.035-.003.002-.002.003-3.149 3.148-.003.002-.002.003-.225.225.023.023a2.691 2.691 0 00.011 3.344l-.022.022 1.923 1.924.031-.031c.025.026.042.057.067.083 7.091 7.091 7.132 18.594.135 25.746l-.014-.014-1.707 1.707h-.002l-.215.215.022.022a2.698 2.698 0 00.16 3.554l-.004.004 3.42 3.42.023-.023a2.691 2.691 0 003.344-.011l.022.022 1.923-1.923-.004-.004c10.838-10.99 10.794-28.745-.138-39.678zm-16.625-6.395a2.04 2.04 0 00-1.031.285l-.018-.032-20.464 11.815v.012l-7.74 4.469H9.016v.04c-.012 0-.024-.004-.037-.004-.842 0-1.525.684-1.525 1.525v20.66c0 .842.683 1.524 1.525 1.524.013 0 .024-.003.037-.004v.041h14.482l11.524 6.653v-.031l16.548 9.555a2.071 2.071 0 003.252-1.698c0-.081-.015-.155-.024-.233h.024V25.64h-.024a2.064 2.064 0 00-2.047-1.837z"
  }));
});
Volume.displayName = 'Volume';
export const VolumeDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/Volume/Volume.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var Volume = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M78.864 17.021c-.026-.026-.056-.042-.082-.067l.008-.008-1.924-1.923-.022.022a2.696 2.696 0 00-3.553.161l-.004-.004-3.419 3.418.023.023a2.693 2.693 0 00.01 3.345l-.022.022.216.216 1.707 1.708.031-.031c.025.026.042.057.067.083 14.358 14.358 14.401 37.688.138 52.104l-.019-.019-1.707 1.707-.216.216.022.022a2.698 2.698 0 00.16 3.553l-.004.004 3.42 3.42.023-.023a2.693 2.693 0 003.345-.011l.022.022.216-.216 1.707-1.707-.004-.004c18.102-18.257 18.058-47.835-.139-66.033z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M69.376 30.198c-.026-.026-.056-.042-.082-.067l.008-.008-1.925-1.923-.022.022a2.7 2.7 0 00-3.554.16l-.004-.004-.035.035-.003.002-.002.003-3.149 3.148-.003.002-.002.003-.225.225.023.023a2.691 2.691 0 00.011 3.344l-.022.022 1.923 1.924.031-.031c.025.026.042.057.067.083 7.091 7.091 7.132 18.594.135 25.746l-.014-.014-1.707 1.707h-.002l-.215.215.022.022a2.698 2.698 0 00.16 3.554l-.004.004 3.42 3.42.023-.023a2.691 2.691 0 003.344-.011l.022.022 1.923-1.923-.004-.004c10.838-10.99 10.794-28.745-.138-39.678zm-16.625-6.395a2.04 2.04 0 00-1.031.285l-.018-.032-20.464 11.815v.012l-7.74 4.469H9.016v.04c-.012 0-.024-.004-.037-.004-.842 0-1.525.684-1.525 1.525v20.66c0 .842.683 1.524 1.525 1.524.013 0 .024-.003.037-.004v.041h14.482l11.524 6.653v-.031l16.548 9.555a2.071 2.071 0 003.252-1.698c0-.081-.015-.155-.024-.233h.024V25.64h-.024a2.064 2.064 0 00-2.047-1.837z"
  }));
});
Volume.displayName = 'Volume';
export var VolumeDimensions = {
  height: 100,
  width: 100
};
